Welcome to mirror list, hosted at ThFree Co, Russian Federation.

git.blender.org/blender.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorTon Roosendaal <ton@blender.org>2003-11-25 21:14:00 +0300
committerTon Roosendaal <ton@blender.org>2003-11-25 21:14:00 +0300
commit595e0e51fd23050933978c326c1e80148ad836ff (patch)
tree30540612c387260d3ccdd01ad1ff06a56b53e291 /source/creator
parentaf1204367798ff49a9d0af7e4fe427a654fa74da (diff)
- forgot to do this... belongs to commit with text:
bug fix: in background render, the default builtin font was not activated for rendering when other fonts were packed too.
Diffstat (limited to 'source/creator')
-rw-r--r--source/creator/creator.c9
1 files changed, 7 insertions, 2 deletions
diff --git a/source/creator/creator.c b/source/creator/creator.c
index c92d034d2a6..9a93767c10e 100644
--- a/source/creator/creator.c
+++ b/source/creator/creator.c
@@ -52,8 +52,10 @@
#include "BKE_utildefines.h"
#include "BKE_blender.h"
+#include "BKE_font.h"
#include "BKE_global.h"
#include "BKE_main.h"
+#include "BKE_packedFile.h"
#include "BKE_scene.h"
#include "BIF_gl.h"
@@ -84,6 +86,7 @@
#include "mydevice.h"
#include "render.h"
#include "nla.h"
+#include "datatoc.h"
/* for passing information between creator and gameengine */
#include "SYS_System.h"
@@ -312,8 +315,10 @@ int main(int argc, char **argv)
/* for all platforms, even windos has it! */
if(G.background) signal(SIGINT, blender_esc); /* ctrl c out bg render */
-
- RE_init_render_data(); /* must be called here because R.winpos from default file */
+ /* background render uses this font too */
+ BKE_font_register_builtin(datatoc_Bfont, datatoc_Bfont_size);
+ /* must be called here because R.winpos from default file */
+ RE_init_render_data();
if(G.background==0) {
for(a=1; a<argc; a++) {